@@ -60,8 +60,8 @@
 #'
 #' @examples
 #' #plotting the random variables and probability values
-#' col<-rainbow(5)
-#' a<-c(.1,.2,.3,1.5,2.15)
+#' col <- rainbow(5)
+#' a <- c(.1,.2,.3,1.5,2.15)
 #' plot(0,0,main="Probability density graph",xlab="Random variable",ylab="Probability density values",
 #' xlim = c(0,1),ylim = c(0,10))
 #' for (i in 1:5)
@@ -177,8 +177,8 @@ dGBeta1<-function(p,a,b,c)
 #'
 #' @examples
 #' #plotting the random variables and probability values
-#' col<-rainbow(5)
-#' a<-c(.1,.2,.3,1.5,2.15)
+#' col <- rainbow(5)
+#' a <- c(.1,.2,.3,1.5,2.15)
 #' plot(0,0,main="Probability density graph",xlab="Random variable",ylab="Probability density values",
 #' xlim = c(0,1),ylim = c(0,10))
 #' for (i in 1:5)
@@ -303,8 +303,8 @@ pGBeta1<-function(p,a,b,c)
 #'
 #' @examples
 #' #plotting the random variables and probability values
-#' col<-rainbow(5)
-#' a<-c(.1,.2,.3,1.5,2.15)
+#' col <- rainbow(5)
+#' a <- c(.1,.2,.3,1.5,2.15)
 #' plot(0,0,main="Probability density graph",xlab="Random variable",ylab="Probability density values",
 #' xlim = c(0,1),ylim = c(0,10))
 #' for (i in 1:5)
@@ -426,8 +426,8 @@ mazGBeta1<-function(r,a,b,c)
 #'
 #' @examples
 #' #plotting the random variables and probability values
-#' col<-rainbow(5)
-#' a<-c(1,2,5,10,0.6)
+#' col <- rainbow(5)
+#' a <- c(1,2,5,10,0.6)
 #' plot(0,0,main="Mcdonald generalized beta-binomial probability function graph",
 #' xlab="Binomial random variable",ylab="Probability function values",xlim = c(0,10),ylim = c(0,0.5))
 #' for (i in 1:5)
@@ -442,8 +442,8 @@ mazGBeta1<-function(r,a,b,c)
 #' dMcGBB(0:10,10,4,2,1)$over.dis.para   #extracting the over dispersion value
 #'
 #' #plotting the random variables and cumulative probability values
-#' col<-rainbow(4)
-#' a<-c(1,2,5,10)
+#' col <- rainbow(4)
+#' a <- c(1,2,5,10)
 #' plot(0,0,main="Cumulative probability function graph",xlab="Binomial random variable",
 #' ylab="Cumulative probability function values",xlim = c(0,10),ylim = c(0,1))
 #' for (i in 1:4)
@@ -565,8 +565,8 @@ dMcGBB<-function(x,n,a,b,c)
 #'
 #' @examples
 #' #plotting the random variables and probability values
-#' col<-rainbow(5)
-#' a<-c(1,2,5,10,0.6)
+#' col <- rainbow(5)
+#' a <- c(1,2,5,10,0.6)
 #' plot(0,0,main="Mcdonald generalized beta-binomial probability function graph",
 #' xlab="Binomial random variable",ylab="Probability function values",xlim = c(0,10),ylim = c(0,0.5))
 #' for (i in 1:5)
@@ -581,8 +581,8 @@ dMcGBB<-function(x,n,a,b,c)
 #' dMcGBB(0:10,10,4,2,1)$over.dis.para   #extracting the over dispersion value
 #'
 #' #plotting the random variables and cumulative probability values
-#' col<-rainbow(4)
-#' a<-c(1,2,5,10)
+#' col <- rainbow(4)
+#' a <- c(1,2,5,10)
 #' plot(0,0,main="Cumulative probability function graph",xlab="Binomial random variable",
 #' ylab="Cumulative probability function values",xlim = c(0,10),ylim = c(0,1))
 #' for (i in 1:4)
@@ -646,8 +646,8 @@ pMcGBB<-function(x,n,a,b,c)
 #' Available at: \url{http://www.tandfonline.com/doi/full/10.1080/03610918.2015.1088024}.
 #'
 #' @examples
-#' No.D.D=0:7            #assigning the random variables
-#' Obs.fre.1=c(47,54,43,40,40,41,39,95)    #assigning the corresponding frequencies
+#' No.D.D <- 0:7            #assigning the random variables
+#' Obs.fre.1 <- c(47,54,43,40,40,41,39,95)    #assigning the corresponding frequencies
 #'
 #' NegLLMcGBB(No.D.D,Obs.fre.1,.2,.3,1)    #acquiring the negative log likelihood value
 #'
@@ -705,13 +705,14 @@ NegLLMcGBB<-function(x,freq,a,b,c)
 #' variables and corresponding frequencies are given.
 #'
 #' @usage
-#' EstMLEMcGBB(x,freq,a,b,c)
+#' EstMLEMcGBB(x,freq,a,b,c,...)
 #'
 #' @param x                  vector of binomial random variables.
 #' @param freq               vector of frequencies.
 #' @param a                  single value for shape parameter alpha representing as a.
 #' @param b                  single value for shape parameter beta representing as b.
 #' @param c                  single value for shape parameter gamma representing as c.
+#' @param ...                mle2 function inputs except data and estimating parameter.
 #'
 #' @details
 #' \deqn{0 < a,b,c}
@@ -722,8 +723,8 @@ NegLLMcGBB<-function(x,freq,a,b,c)
 #' error messages will be provided to go further.
 #'
 #' @return
-#' \code{EstMLEMcGBB} here is used as a input parameter for the \code{mle2} function of \pkg{bbmle}
-#' package.
+#' \code{EstMLEMcGBB} here is used as a wrapper for the \code{mle2} function of \pkg{bbmle} package
+#' therefore output is of class of mle2.
 #'
 #' @references
 #' Manoj, C., Wijekoon, P. & Yapa, R.D., 2013. The McDonald Generalized Beta-Binomial Distribution: A New
@@ -744,18 +745,35 @@ NegLLMcGBB<-function(x,freq,a,b,c)
 #' \code{\link[bbmle]{mle2}}
 #'
 #' @examples
-#' No.D.D=0:7                   #assigning the random variables
-#' Obs.fre.1=c(47,54,43,40,40,41,39,95)  #assigning the corresponding frequencies
+#' No.D.D <- 0:7                   #assigning the random variables
+#' Obs.fre.1 <- c(47,54,43,40,40,41,39,95)  #assigning the corresponding frequencies
 #'
+#' \dontrun{
 #' #estimating the parameters using maximum log likelihood value and assigning it
-#'
-#' parameters=suppressWarnings(bbmle::mle2(EstMLEMcGBB,start = list(a=0.1,b=0.1,c=0.2),
-#' data = list(x=No.D.D,freq=Obs.fre.1)))
+#' parameters <- EstMLEMcGBB(x=No.D.D,freq=Obs.fre.1,a=0.1,b=0.1,c=0.2)
 #'
 #' bbmle::coef(parameters)         #extracting the parameters
-#'
+#'         }
 #' @export
-EstMLEMcGBB<-function(x,freq,a,b,c)
+EstMLEMcGBB<-function(x,freq,a,b,c,...)
+{
+  suppressWarnings2 <-function(expr, regex=character())
+  {
+    withCallingHandlers(expr, warning=function(w)
+    {
+      if (length(regex) == 1 && length(grep(regex, conditionMessage(w))))
+      {
+        invokeRestart("muffleWarning")
+      }
+    }                  )
+  }
+  output<-suppressWarnings2(bbmle::mle2(.EstMLEMcGBB,data=list(x=x,freq=freq),
+                                        start = list(a=a,b=b,c=c),...),"NaN")
+  return(output)
+}
+
+
+.EstMLEMcGBB<-function(x,freq,a,b,c)
 {
   #with respective to using bbmle package function mle2 there is no need impose any restrictions
   #therefor the output is directly a single numeric value for the negative log likelihood value of
@@ -852,20 +870,19 @@ EstMLEMcGBB<-function(x,freq,a,b,c)
 #' \code{\link[bbmle]{mle2}}
 #'
 #' @examples
-#' No.D.D=0:7       #assigning the random variables
-#' Obs.fre.1=c(47,54,43,40,40,41,39,95)          #assigning the corresponding frequencies
+#' No.D.D <- 0:7       #assigning the random variables
+#' Obs.fre.1 <- c(47,54,43,40,40,41,39,95)          #assigning the corresponding frequencies
 #'
-#' #estimating the parameters using maximum log likelihood value and assigning it
 #' \dontrun{
-#' parameters=suppressWarnings(bbmle::mle2(EstMLEMcGBB,start = list(a=0.1,b=0.1,c=0.2),
-#' data = list(x=No.D.D,freq=Obs.fre.1)))
+#' #estimating the parameters using maximum log likelihood value and assigning it
+#' parameters <- EstMLEMcGBB(x=No.D.D,freq=Obs.fre.1,a=0.1,b=0.1,c=3.2)
 #'
-#' aMcGBB=bbmle::coef(parameters)[1]         #assigning the estimated a
-#' bMcGBB=bbmle::coef(parameters)[2]         #assigning the estimated b
-#' cMcGBB=bbmle::coef(parameters)[3]         #assigning the estimated c
+#' aMcGBB <- bbmle::coef(parameters)[1]         #assigning the estimated a
+#' bMcGBB <- bbmle::coef(parameters)[2]         #assigning the estimated b
+#' cMcGBB <- bbmle::coef(parameters)[3]         #assigning the estimated c
 #'
 #' #fitting when the random variable,frequencies,shape parameter values are given.
-#' results<-fitMcGBB(No.D.D,Obs.fre.1,aMcGBB,bMcGBB,cMcGBB)
+#' results <- fitMcGBB(No.D.D,Obs.fre.1,aMcGBB,bMcGBB,cMcGBB)
 #' results
 #'
 #' #extracting the expected frequencies
@@ -904,19 +921,19 @@ EstMLEMcGBB<-function(x,freq,a,b,c)
     #checking if df is less than or equal to zero
     if(df<0 | df==0)
     {
-      warning("Degrees of freedom cannot be less than or equal to zero")
+      stop("Degrees of freedom cannot be less than or equal to zero")
     }
     #checking if any of the expected frequencies are less than five and greater than zero, if so
     #a warning message is provided in interpreting the results
     if(min(exp.freq)<5 && min(exp.freq) > 0)
     {
-      warning("Chi-squared approximation may be doubtful because expected frequency is less than 5")
+      message("Chi-squared approximation may be doubtful because expected frequency is less than 5")
     }
     #checking if expected frequency is zero, if so providing a warning message in interpreting
     #the results
     if(min(exp.freq)==0)
     {
-      warning("Chi-squared approximation is not suitable because expected frequency approximates to zero")
+      message("Chi-squared approximation is not suitable because expected frequency approximates to zero")
     }
     #calculating Negative Loglikelihood value and AIC
     NegLL<-NegLLMcGBB(x,obs.freq,a,b,c)
@@ -948,7 +965,8 @@ print.fitMB<-function(x,...)
   cat("\nChi-squared test for Mc-Donald Generalized Beta-Binomial Distribution \n\t
       Observed Frequency : ",x$obs.freq,"\n\t
       expected Frequency : ",x$exp.freq,"\n\t
-      estimated a parameter :",x$a, "  ,estimated b parameter :",x$b," ,estimated c parameter :",x$c,"\n\t
+      estimated a parameter :",x$a, "  ,estimated b parameter :",x$b,",\n\t
+      estimated c parameter :",x$c,"\n\t
       X-squared :",x$statistic,"  ,df :",x$df,"  ,p-value :",x$p.value,"\n\t
       over dispersion :",x$over.dis.para,"\n")
 }
@@ -962,7 +980,8 @@ summary.fitMB<-function(object,...)
   cat("\nChi-squared test for Mc-Donald Generalized Beta-Binomial Distribution \n\t
       Observed Frequency : ",object$obs.freq,"\n\t
       expected Frequency : ",object$exp.freq,"\n\t
-      estimated a parameter :",object$a,"  ,estimated b parameter :",object$b," ,estimated c value :",object$it,"\n\t
+      estimated a parameter :",object$a,"  ,estimated b parameter :",object$b,",\n\t
+      estimated c parameter :",object$c,"\n\t
       X-squared :",object$statistic,"  ,df :",object$df,"  ,p-value :",object$p.value,"\n\t
       over dispersion :",object$over.dis.para,"\n\t
       Negative Loglikehood value :",object$NegLL,"\n\t
